'use strict';
'use es6';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _Coordinate = require('../data/Coordinate');

var _Coordinate2 = _interopRequireDefault(_Coordinate);

var _Leg = require('../data/Leg');

var _Leg2 = _interopRequireDefault(_Leg);

var _Step = require('../data/Step');

var _Step2 = _interopRequireDefault(_Step);

var _TransitAgency = require('../data/TransitAgency');

var _TransitAgency2 = _interopRequireDefault(_TransitAgency);

var _TransitDetails = require('../data/TransitDetails');

var _TransitDetails2 = _interopRequireDefault(_TransitDetails);

var _TransitLine = require('../data/TransitLine');

var _TransitLine2 = _interopRequireDefault(_TransitLine);

var _TransitStop = require('../data/TransitStop');

var _TransitStop2 = _interopRequireDefault(_TransitStop);

var _TransitVehicle = require('../data/TransitVehicle');

var _TravelMode = require('../data/TravelMode');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var GoogleDirectionsTranslationService = function () {
  function GoogleDirectionsTranslationService() {
    _classCallCheck(this, GoogleDirectionsTranslationService);
  }

  _createClass(GoogleDirectionsTranslationService, null, [{
    key: 'translateDirections',
    value: function translateDirections(directions) {
      var routes = [];
      directions.routes.forEach(function (route) {
        var legs = [];
        route.legs.forEach(function (leg) {
          legs.push(GoogleDirectionsTranslationService.translateLeg(leg));
        });
        routes.push(legs);
      });
      return routes;
    }
  }, {
    key: 'translateLeg',
    value: function translateLeg(leg) {
      var steps = [];
      leg.steps.forEach(function (step) {
        return steps.push(GoogleDirectionsTranslationService.translateStep(step));
      });

      return new _Leg2.default({
        arrivalTimestamp: leg.arrival_time.value,
        departureTimestamp: leg.departure_time.value,
        distanceMeters: leg.distance.value,
        durationSeconds: leg.duration.value,
        endAddress: leg.end_address,
        endLocation: new _Coordinate2.default({
          latitude: leg.end_location.lat,
          longitude: leg.end_location.lng
        }),
        startAddress: leg.start_address,
        startLocation: new _Coordinate2.default({
          latitude: leg.start_location.lat,
          longitude: leg.start_location.lng
        }),
        steps: steps
      });
    }
  }, {
    key: 'translateStep',
    value: function translateStep(step) {
      var transitDetails = new _TransitDetails2.default();
      if ('transit_details' in step) {
        transitDetails = GoogleDirectionsTranslationService.translateTransitDetails(step.transit_details);
      }

      return new _Step2.default({
        distanceMeters: step.distance.value,
        durationSeconds: step.duration.value,
        endLocation: new _Coordinate2.default({
          latitude: step.end_location.lat,
          longitude: step.end_location.lng
        }),
        htmlInstructions: step.html_instructions,
        startLocation: new _Coordinate2.default({
          latitude: step.start_location.lat,
          longitude: step.start_location.lng
        }),
        transitDetails: transitDetails,
        travelMode: (0, _TravelMode.translateToTravelMode)(step.travel_mode)
      });
    }
  }, {
    key: 'translateTransitDetails',
    value: function translateTransitDetails(details) {
      return new _TransitDetails2.default({
        arrivalTransitStop: GoogleDirectionsTranslationService.translateTransitStop(details.arrival_stop),
        arrivalTimestamp: details.arrival_time.value,
        departureTransitStop: GoogleDirectionsTranslationService.translateTransitStop(details.departure_stop),
        departureTimestamp: details.departure_time.value,
        headsign: details.headsign,
        line: GoogleDirectionsTranslationService.translateTransitLine(details.line),
        stopCount: details.num_stops
      });
    }
  }, {
    key: 'translateTransitStop',
    value: function translateTransitStop(stop) {
      return new _TransitStop2.default({
        location: new _Coordinate2.default({
          latitude: stop.location.lat,
          longitude: stop.location.lng
        }),
        name: stop.name
      });
    }
  }, {
    key: 'translateTransitLine',
    value: function translateTransitLine(line) {
      var name = '';
      if ('name' in line) {
        name = line.name;
      }

      var shortName = '';
      if ('short_name' in line) {
        shortName = line.short_name;
      }

      var color = '';
      if ('color' in line) {
        color = line.color;
      }

      return new _TransitLine2.default({
        agencies: GoogleDirectionsTranslationService.translateAgencies(line.agencies),
        color: color,
        name: name,
        shortName: shortName,
        vehicle: (0, _TransitVehicle.translateToTransitVehicle)(line.vehicle.type)
      });
    }
  }, {
    key: 'translateAgencies',
    value: function translateAgencies(agencies) {
      var translatedAgencies = [];
      agencies.forEach(function (agency) {
        var name = '';
        if ('name' in agency) {
          name = agency.name;
        }

        var phone = '';
        if ('phone' in agency) {
          phone = agency.phone;
        }

        var url = '';
        if ('url' in agency) {
          url = agency.url;
        }

        translatedAgencies.push(new _TransitAgency2.default({
          name: name,
          phoneNumber: phone,
          uri: url
        }));
      });
      return translatedAgencies;
    }
  }]);

  return GoogleDirectionsTranslationService;
}();

exports.default = GoogleDirectionsTranslationService;